pub struct Flexible<'de, T> { /* private fields */ }Expand description
A flexible FIDL response.
Implementations
Sourceimpl<T> Flexible<'_, T>
impl<T> Flexible<'_, T>
Sourcepub fn is_framework_err(&self) -> bool
pub fn is_framework_err(&self) -> bool
Returns whether the flexible response is FrameworkErr.
Sourcepub fn framework_err(&self) -> Option<FrameworkError>
pub fn framework_err(&self) -> Option<FrameworkError>
Returns the FrameworkErr value of the response, if any.
Sourcepub fn unwrap_framework_err(&self) -> FrameworkError
pub fn unwrap_framework_err(&self) -> FrameworkError
Returns the contained FrameworkErr value.
Panics if the response was not FrameworkErr.
Sourcepub fn as_ref(&self) -> Flexible<&T>
pub fn as_ref(&self) -> Flexible<&T>
Returns a Flexible of a reference to the value or framework error.
Sourcepub fn as_result(&self) -> Result<&T, FrameworkError>
pub fn as_result(&self) -> Result<&T, FrameworkError>
Returns a Result of the Ok value and a potential FrameworkError.
Sourcepub fn to_flexible(self) -> Flexible<T>
pub fn to_flexible(self) -> Flexible<T>
Returns a Flexible of an Owned value or framework error.